@@ -19,10 +19,11 @@ cd build
 cmake -D COMPRESSED_AUDIO=mp3 ..
 make createMp3FromOgg
 make BundleConvertedOggs
-make getSvnTranslations
+# don't fetch translations, instead copy the curated list from release source tarball before running this script
+# make getSvnTranslations
 make BuildTranslations
 make BundleTranslations
-rsync -a ../converted_ogg_to_mp3-*.7z translations-*.7z gcompris.net:/var/www/download
+#rsync -a ../converted_ogg_to_mp3-*.7z translations-*.7z gcompris.net:/var/www/download
 
 #
 # Then on Windows use the targets:
