@@ -1,26 +1,15 @@
 /* GCompris - babymatch.js
  *
- * Copyright (C) 2015 Pulkit Gupta
+ * SPDX-FileCopyrightText: 2015 Pulkit Gupta
  *
  * Authors:
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (GTK+ version)
  *   Pulkit Gupta <pulkitgenius@gmail.com> (Qt Quick port)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 
 var useMultipleDataset;
@@ -66,7 +55,7 @@ function resetData() {
     showText = [];
 
     items.backgroundPiecesModel.clear();
-    items.backgroundImage.source = "";
+    items.backgroundImageSource.source = "";
 }
 
 function stop() {
@@ -169,11 +158,11 @@ function initLevel() {
         //Create static background pieces
         else {
             if(levelData.levels[i].type === "SHAPE_BACKGROUND_IMAGE") {
-                items.backgroundImage.source = imagesUrl + levelData.levels[i].pixmapfile;
+                items.backgroundImageSource.source = imagesUrl + levelData.levels[i].pixmapfile;
                 if(levelData.levels[i].width)
-                    items.backgroundImage.sourceSize.width = levelData.levels[i].width;
+                    items.backgroundImageSource.sourceSize.width = levelData.levels[i].width;
                 if(levelData.levels[i].height)
-                    items.backgroundImage.sourceSize.height = levelData.levels[i].height;
+                    items.backgroundImageSource.sourceSize.height = levelData.levels[i].height;
             }
             else {
                 items.backgroundPiecesModel.append( {
@@ -259,3 +248,9 @@ function highLightSpot(stopItem, tile) {
         }
     }
 }
+
+function clearHighLightSpots() {
+    for(var i = 0 ; i < spots.length ; ++ i) {
+        spots[i].hide();
+    }
+}
