@@ -28,6 +28,9 @@ function start(items_) {
 }
 
 function stop() {
+    items.trigComputerMove.stop();
+    items.redoTimer.stop();
+    items.timerSwap.stop();
 }
 
 function initLevel() {
