@@ -1,26 +1,16 @@
 /* GCompris - clickgame.js
  *
- * Copyright (C) 2014 Bruno Coudoin <bruno.coudoin@gcompris.net>
+ * SPDX-FileCopyrightText: 2014 Bruno Coudoin <bruno.coudoin@gcompris.net>
  *
  * Authors:
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (GTK+ version)
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (Qt Quick port)
+ *   Timothée Giet <animtim@gmail.com> (animation refactoring)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import GCompris 1.0 as GCompris
 
 var fishes = [
@@ -191,27 +181,27 @@ var fishes = [
 var levelProperty = [
             {
                 "nbFish": 5,
-                "minDuration": 20000
+                "minDuration": 2000
             },
             {
                 "nbFish": 7,
-                "minDuration": 15000
+                "minDuration": 1500
             },
             {
                 "nbFish": 10,
-                "minDuration": 10000
+                "minDuration": 1000
             },
             {
                 "nbFish": 12,
-                "minDuration": 8000
+                "minDuration": 800
             },
             {
                 "nbFish": 15,
-                "minDuration": 6000
+                "minDuration": 600
             },
             {
                 "nbFish": 18,
-                "minDuration": 4000
+                "minDuration": 400
             }
         ]
 var currentImageId = 0
@@ -265,7 +255,7 @@ function nextLevel() {
     if(levelProperty.length <= ++currentLevel) {
         currentLevel = 0
     }
-    
+
     initLevel();
 }
 
@@ -281,6 +271,7 @@ function createFish(minDuration) {
     var fishSource = fishes[Math.floor(Math.random() * fishes.length)]
     var minY = items.score.y + items.score.height
     var maxY = bar.y - fishSource.height - bar.height
+    var maxX = background.width - fishSource.width
     var fish = component.createObject(
                 background,
                 {
@@ -288,12 +279,14 @@ function createFish(minDuration) {
                     "background": background,
                     "bar": bar,
                     "y": (Math.random() * (maxY - minY + 1)) + minY,
+                    "x": (Math.random() * (maxX + 1)),
                     "width": fishSource.width * 1.1 * GCompris.ApplicationInfo.ratio,
                     "height": fishSource.height * 1.1 * GCompris.ApplicationInfo.ratio,
                     "source": "qrc:/gcompris/src/activities/clickgame/resource/" +
                               fishSource.imgName,
                     "frameCount": fishSource.nbFrame,
-                    "duration": minDuration + Math.floor(Math.random() * 5000)
+                    "xSpeed": (background.width + fishSource.width * 1.1 * GCompris.ApplicationInfo.ratio) / (minDuration + Math.floor(Math.random() * 500)),
+                    "ySpeed": (background.height + fishSource.height * 1.1 * GCompris.ApplicationInfo.ratio) / (minDuration * 2 + Math.floor(Math.random() * 500))
                 });
     if (fish === null) {
         // Error Handling
