@@ -1,23 +1,12 @@
 /* GCompris - colormix.js'
 *
-* Copyright (C) 2014 Stephane Mankowski <stephane@mankowski.fr>
+* SPDX-FileCopyrightText: 2014 Stephane Mankowski <stephane@mankowski.fr>
 *
 * Authors:
 *   Matilda Bernard <serah4291@gmail.com> (GTK+ version)
 *   Stephane Mankowski <stephane@mankowski.fr> (Qt Quick port)
 *
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU General Public License as published by
-*   the Free Software Foundation; either version 3 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU General Public License
-*   along with this program; if not, see <https://www.gnu.org/licenses/>.
+*   SPDX-License-Identifier: GPL-3.0-or-later
 */
 var url = "qrc:/gcompris/src/activities/color_mix/resource/"
 
@@ -52,6 +41,9 @@ function initLevel() {
     items.currentColor1 = 0
     items.currentColor2 = 0
     items.currentColor3 = 0
+
+    /* Enable OK button */
+    items.okEnabled = true
 }
 
 function getColor(i1, i2, i3) {
