@@ -1,23 +1,12 @@
 /* GCompris - findit.js
  *
- * Copyright (C) 2015 Bruno Coudoin
+ * SPDX-FileCopyrightText: 2015 Bruno Coudoin
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var url = "qrc:/gcompris/src/activities/colors/resource/"
@@ -63,6 +52,7 @@ function initLevel() {
     dataset[currentLevel] = Core.shuffle(dataset[currentLevel])
     hasWon = false
     initQuestion()
+    items.objectSelected = false
 }
 
 function initQuestion() {
