@@ -8,21 +8,10 @@
  *   Johnny Jazeix <jazeix@gmail.com> (Qt Quick hanoi simplified port)
  *   Timothée Giet <animtim@gmail.com> (Graphics refactoring)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var url = "qrc:/gcompris/src/activities/hanoi_real/resource/"
@@ -42,21 +31,21 @@ var symbols = [
 ]
 
 var colors = [
-    "#e4230b", // red
-    "#2cd60a", // green
-    "#0b62e4", // blue
-    "#ddb20b", // yellow
-    "#e40bb6", // magenta
-    "#0bb1e4", // cyan
-    "#e4900b", // orange
-    "#bc0be4", // purple
-    "#e43e0b", // red2
-    "#0ad618", // green2
-    "#2749f5", // blue2
-    "#ddc70b", // yellow2
-    "#e40b80", // magenta2
-    "#0b80e4", // cyan2
-    "#e4710b"  // orange2
+    "#e41c1c", // red 0
+    "#79e41c", // green 65
+    "#1c8fe4", // blue 146
+    "#e4bb1c", // yellow 34
+    "#e41c92", // magenta 230
+    "#1dc0e3", // cyan 135
+    "#e3711d", // orange 18
+    "#a91de3", // purple 200
+    "#e44b1c", // red2 10
+    "#1ce463", // green2 100
+    "#1c4ce4", // blue2 160
+    "#e4e01c", // yellow2 42
+    "#f20ee5", // magenta2 215
+    "#1de3da", // cyan2 126
+    "#e4921c"  // orange2 25
 ]
 
 var nbTowersLessExpectedAndResultOnes
@@ -127,7 +116,7 @@ function initLevel() {
         for(var i = 0 ; i < (items.numberOfDisc-nbMaxItemsByTower); ++i) {
             var index = Math.floor(Math.random() * symbols.length);
             items.discRepeater.itemAt(i).text = symbols[index];
-            items.discRepeater.itemAt(i).color = colors[index];
+            items.discRepeater.itemAt(i).baseColor = colors[index];
         }
         // Fill the text discs avoiding duplicates
         var currentAnswerId = items.numberOfDisc-nbMaxItemsByTower;
@@ -136,7 +125,7 @@ function initLevel() {
             var id = Math.floor(Math.random() * (items.numberOfDisc-nbMaxItemsByTower));
             if(goodAnswerIndices.indexOf(id) == -1) {
                 items.discRepeater.itemAt(currentAnswerId).text = items.discRepeater.itemAt(id).text;
-                items.discRepeater.itemAt(currentAnswerId).color = items.discRepeater.itemAt(id).color;
+                items.discRepeater.itemAt(currentAnswerId).baseColor = items.discRepeater.itemAt(id).baseColor;
                 goodAnswerIndices.push(id);
                 currentAnswerId ++;
             }
@@ -187,7 +176,7 @@ function placeDiscsAtOrigin() {
     if(activityMode == "real") {
         for(var i = 0 ; i < items.numberOfDisc ; ++i) {
             placeDisc(items.discRepeater.itemAt(i), items.towerModel.itemAt(0))
-            items.discRepeater.itemAt(i).color = colors[i];
+            items.discRepeater.itemAt(i).baseColor = colors[i];
         }
     }
     else {
