@@ -1,28 +1,17 @@
 /* GCompris - programmingMaze.js
  *
- * Copyright (C) 2015 Siddhesh Suthar <siddhesh.it@gmail.com>
- * Copyright (C) 2018 Aman Kumar Gupta <gupta2140@gmail.com>
+ * SPDX-FileCopyrightText: 2015 Siddhesh Suthar <siddhesh.it@gmail.com>
+ * SPDX-FileCopyrightText: 2018 Aman Kumar Gupta <gupta2140@gmail.com>
  *
  * Authors:
  *   Siddhesh Suthar <siddhesh.it@gmail.com>
  *   Aman Kumar Gupta <gupta2140@gmail.com>
  *   Timothée Giet <animtim@gcompris.net> (Layout and graphics rework)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 
 // possible instructions
@@ -30,6 +19,7 @@ var MOVE_FORWARD = "move-forward"
 var TURN_LEFT = "turn-left"
 var TURN_RIGHT = "turn-right"
 var CALL_PROCEDURE = "call-procedure"
+var EXECUTE_LOOPS = "execute-loop"
 
 var mazeBlocks
 
@@ -40,11 +30,12 @@ var stepX
 var stepY
 
 /**
- * Lookup tables of instruction objects for main and procedure areas which will be stored here on creation and can be
+ * Lookup tables of instruction objects for main, procedure and loop areas which will be stored here on creation and can be
  * accessed when required to execute.
  */
 var mainInstructionObjects = []
 var procedureInstructionObjects = []
+var loopInstructionObjects = []
 
 // New rotation of Tux on turning.
 var changedRotation
@@ -55,6 +46,9 @@ var deadEndPoint = false
 // Stores the index of mainInstructionObjects[] which is going to be processed
 var codeIterator = 0
 
+// Stores the number of loops needed
+var loopsNumber
+
 /**
  * Stores if the reset is done only when Tux is clicked.
  *
@@ -78,6 +72,12 @@ var WEST = 90
 var SOUTH = 180
 var EAST = 270
 
+//Used to increment or decrement the loop counter, and display one as an initial value for the loop counter in the tutorial base.
+var LoopEnumValues = {
+    PLUS_SIGN : "\u002B",
+    MINUS_SIGN : "\u2212"
+}
+
 /**
  * Stores the qml file components of all the instructions used in the activity.
  *
@@ -87,7 +87,8 @@ var instructionComponents = {
     "move-forward": Qt.createComponent(url + "instructions/MoveForward.qml"),
     "turn-left": Qt.createComponent(url + "instructions/TurnLeftOrRight.qml"),
     "turn-right": Qt.createComponent(url + "instructions/TurnLeftOrRight.qml"),
-    "call-procedure": Qt.createComponent(url + "instructions/Procedure.qml")
+    "call-procedure": Qt.createComponent(url + "instructions/Procedure.qml"),
+    "execute-loop": Qt.createComponent(url + "instructions/Loop.qml")
 }
 
 var mainTutorialInstructions = [
@@ -97,14 +98,14 @@ var mainTutorialInstructions = [
                                     qsTr("<b>1. Move forward:</b> Moves Tux one step forward in the direction it is facing.") + "</li><li>" +
                                     qsTr("<b>2. Turn left:</b> Turns Tux to the left.") + "</li><li>" +
                                     qsTr("<b>3. Turn right:</b> Turns Tux to the right.") + "</li>",
-                "instructionImage": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial1.png"
+                "instructionQml": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial1.qml"
             },
             {
                 "instruction": "<b><h7>" + qsTr("Main Function:") + "</h7></b>" +
                                     qsTr("The execution of the code starts here.") + "<li>" +
                                     qsTr("-Click on any instruction in the <b>instruction area</b> to add it to the <b>Main Function</b>.") + "</li><li>" +
                                     qsTr("-The instructions will execute in order until there's none left, or until a dead-end, or when Tux reaches the fish.") + "</li>",
-                "instructionImage": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial2.png"
+                "instructionQml": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial2.qml"
             },
         ]
 
@@ -113,19 +114,23 @@ var procedureTutorialInstructions = [
                 "instruction": "<b><h7>" + qsTr("Procedure:") + "</h7></b>" +
                                     qsTr("<b>Procedure</b> is a reusable set of instructions which can be <b>used in the code by calling it where needed</b>.") + "<li>" +
                                     qsTr("-To <b>switch</b> between the <b>Procedure area</b> and the <b>Main Function area</b> to add your code, click on the <b>Procedure</b> or <b>Main Function</b> label.") + "</li>",
-                "instructionImage": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial3.png"
+                "instructionQml": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial3.qml"
             },
         ]
 
-// Mode of the activity: basic or loop
-var activityMode
+var loopTutorialInstructions = [
+            {
+                "instruction": "<b><h7>" + qsTr("Loop:") + "</h7></b>" +
+                                    qsTr("<b>Loop</b> is a sequence of instructions that is <b>continually repeated the number of times defined by the number inside it</b>.") + "<li>" +
+                                    qsTr("-To <b>switch</b> between the <b>Loop area</b> and the <b>Main Function area</b> to add your code, click on the <b>Loop</b> or <b>Main Function</b> label.") + "</li>",
+                "instructionQml": "qrc:/gcompris/src/activities/programmingMaze/resource/tutorial4.qml"
+            }
+        ]
 
-function start(items_, mode_, datasetUrl_) {
+function start(items_) {
     items = items_
-    items.dataset.source = datasetUrl_
-    activityMode = mode_
     currentLevel = 0
-    mazeBlocks = items.dataset.item.levels
+    mazeBlocks = items.levels
     numberOfLevel = mazeBlocks.length
     resetTux = false
     initLevel()
@@ -139,7 +144,7 @@ function stop() {
  * This function creates and populate instruction objects for main as well as procedure area.
  *
  * These are stored in the lookup table, provided in the parameter as "instructionObjects".
- * The instructions are then connected to the slots of their code area (main or procedure), provided as "instructionCodeArea" in the parameter.
+ * The instructions are then connected to the slots of their code area (main or procedure/loops), provided as "instructionCodeArea" in the parameter.
  *
  * The instructions can now be obtained from the look-up tables and executed when called.
  *
@@ -156,27 +161,39 @@ function createInstructionObjects(instructionObjects, instructionCodeArea) {
 }
 
 function createInstruction(instructionObjects, instructionName, instructionCodeArea) {
-	if(instructionName == TURN_LEFT || instructionName == TURN_RIGHT)
-	    instructionObjects[instructionName] = instructionComponents[instructionName].createObject(instructionCodeArea, { "turnDirection": instructionName })
-	else
-	    instructionObjects[instructionName] = instructionComponents[instructionName].createObject(instructionCodeArea)
+    if(instructionName === TURN_LEFT || instructionName === TURN_RIGHT) {
+        instructionObjects[instructionName] = instructionComponents[instructionName].createObject(instructionCodeArea, { "turnDirection": instructionName })
+    }
+    else {
+        instructionObjects[instructionName] = instructionComponents[instructionName].createObject(instructionCodeArea)
+    }
 
-	instructionObjects[instructionName].foundDeadEnd.connect(instructionCodeArea.deadEnd)
-	instructionObjects[instructionName].executionComplete.connect(instructionCodeArea.checkSuccessAndExecuteNextInstruction)
+    instructionObjects[instructionName].foundDeadEnd.connect(instructionCodeArea.deadEnd)
+    instructionObjects[instructionName].executionComplete.connect(instructionCodeArea.checkSuccessAndExecuteNextInstruction)
 }
 
 // Destroy instruction objects from the look-up tables
 function destroyInstructionObjects() {
+    var i
     var instructionList = Object.keys(mainInstructionObjects)
-    for(var i = 0; i < instructionList.length; i++)
+    for(i = 0; i < instructionList.length; i++) {
         mainInstructionObjects[instructionList[i]].destroy()
+    }
 
     instructionList = Object.keys(procedureInstructionObjects)
-    for(var i = 0; i < instructionList.length; i++)
+    for(i = 0; i < instructionList.length; i++) {
         procedureInstructionObjects[instructionList[i]].destroy()
+    }
+
+    instructionList = Object.keys(loopInstructionObjects)
+    for(i = 0; i < instructionList.length; i++) {
+        loopInstructionObjects[instructionList[i]].destroy()
+    }
+
 
     mainInstructionObjects = []
     procedureInstructionObjects = []
+    loopInstructionObjects = []
 }
 
 function initLevel() {
@@ -184,15 +201,21 @@ function initLevel() {
         return
 
     items.bar.level = currentLevel + 1
+    loopsNumber = 1
     destroyInstructionObjects()
 
     var levelInstructions = mazeBlocks[currentLevel].instructions
 
-    if(levelInstructions.indexOf(CALL_PROCEDURE) != -1)
+    if(levelInstructions.indexOf(CALL_PROCEDURE) !== -1)
         items.currentLevelContainsProcedure = true
     else
         items.currentLevelContainsProcedure = false
 
+    if(levelInstructions.indexOf(EXECUTE_LOOPS) !== -1)
+        items.currentLevelContainsLoop = true
+    else
+        items.currentLevelContainsLoop = false
+
     // Create, populate and connect signals of instructions for main function code area and store them in mainInstructionObjects.
     createInstructionObjects(mainInstructionObjects, items.background)
 
@@ -202,13 +225,26 @@ function initLevel() {
             items.tutorialImage.visible = true
         }
 
-        // Create procedure object in the main look-up table ,if the level has procedure/loop, to execute it for procedure/loop calls from the main code area.
+        // Create procedure object in the main look-up table ,if the level has procedure, to execute it for procedure/loop calls from the main code area.
         createInstruction(mainInstructionObjects, CALL_PROCEDURE, items.background)
 
-        // Create, populate and connect signals of instructions for procedure code area if the level has procedure/loop.
+        // Create, populate and connect signals of instructions for procedure code area if the level has procedure.
         createInstructionObjects(procedureInstructionObjects, mainInstructionObjects[CALL_PROCEDURE])
     }
 
+    if(items.currentLevelContainsLoop) {
+        if(!items.tutorialImage.shownLoopTutorialInstructions) {
+            items.tutorialImage.shownLoopTutorialInstructions = true
+            items.tutorialImage.visible = true
+        }
+
+        if(resetTux) {
+            loopsNumber = items.loopCounterSelection.loopNumber
+        }
+
+        createLoopObjectAndInstructions()
+    }
+
     // Stores the co-ordinates of the tile blocks in the current level
     var currentLevelBlocksCoordinates = mazeBlocks[currentLevel].map
 
@@ -218,6 +254,7 @@ function initLevel() {
         items.mainFunctionModel.clear()
         items.procedureModel.clear()
         items.numberOfInstructionsAdded = 0
+        items.loopCounterSelection.loopNumber = loopsNumber;
     }
 
     stepX = items.mazeModel.itemAt(0).width
@@ -239,7 +276,6 @@ function initLevel() {
 
     changedRotation = EAST
     deadEndPoint = false
-    items.isTuxMouseAreaEnabled = false
     items.isRunCodeEnabled = true
     items.maxNumberOfInstructionsAllowed = mazeBlocks[currentLevel].maxNumberOfInstructions
     items.constraintInstruction.show()
@@ -251,6 +287,14 @@ function initLevel() {
     codeIterator = 0
 }
 
+function createLoopObjectAndInstructions() {
+    // Create loop object in the main look-up table ,if the activity mode is loops, to execute it loops from the main code area.
+    createInstruction(mainInstructionObjects, EXECUTE_LOOPS, items.background)
+
+    // Create, populate and connect signals of instructions for loop code area itself.
+    createInstructionObjects(loopInstructionObjects, mainInstructionObjects[EXECUTE_LOOPS])
+}
+
 function resetCodeAreasIndices() {
     items.instructionArea.currentIndex = -1
     items.mainFunctionCodeArea.currentIndex = -1
@@ -268,10 +312,16 @@ function runCode() {
 
     var instructionName
 
-    // Append all the procedure instructions to the procedure area object.
+    // Append all the procedure instructions to the procedure area object in basic mode.
+    // Append all the loop instructions to the loop area object in loops mode.
     for(var j = 0; j < items.procedureModel.count; j++) {
         instructionName = items.procedureModel.get(j).name
-        mainInstructionObjects[CALL_PROCEDURE].procedureCode.append({ "name" : instructionName })
+        if(items.currentLevelContainsProcedure) {
+            mainInstructionObjects[CALL_PROCEDURE].procedureCode.append({ "name" : instructionName })
+        }
+        else {
+            mainInstructionObjects[EXECUTE_LOOPS].loopCode.append({ "name" : instructionName })
+        }
     }
 
     items.isRunCodeEnabled = false
@@ -291,13 +341,15 @@ function executeNextInstruction() {
 
 function deadEnd() {
     deadEndPoint = true
-    resetTux = true
-    items.isTuxMouseAreaEnabled = true
-    items.constraintInstruction.show()
     items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/brick.wav")
     items.bonus.bad("tux")
 }
 
+function resetTuxPosition() {
+    resetTux = true
+    initLevel()
+}
+
 function checkSuccessAndExecuteNextInstruction() {
     var fishX = mazeBlocks[currentLevel].fish.x
     var fishY = mazeBlocks[currentLevel].fish.y
