@@ -1,25 +1,14 @@
 /* GCompris - TicTacToe.js
  *
- * Copyright (C) 2014 Pulkit Gupta <pulkitgenius@gmail.com>
+ * SPDX-FileCopyrightText: 2014 Pulkit Gupta <pulkitgenius@gmail.com>
  *
  * Authors:
  *   Pulkit Gupta <pulkitgenius@gmail.com>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 
 var currentLevel = 0
 var numberOfLevel = 6
@@ -511,12 +500,11 @@ function continueGame() {
                 items.player2score.win()
             }
             items.bonus.good("flower")
-            items.bonus.isWin = false
         }
         else if(items.counter == 9) {
             items.player1score.endTurn();
             items.player2score.endTurn();
-            items.bonus.bad("tux")
+            items.bonus.bad("flower")
         }
         else
             changeScale()
@@ -531,13 +519,13 @@ function continueGame() {
             } 
             else {
                 items.player2score.win()
-                items.bonus.bad("tux")
+                items.bonus.bad("flower")
             }
         }
         else if(items.counter == 9) {
             items.player1score.endTurn();
             items.player2score.endTurn();
-            items.bonus.bad("tux")
+            items.bonus.bad("flower")
         }
         else 
             changeScale()
