@@ -145,7 +145,6 @@ void ActivityInfoTree::filterByTag(const QString &tag, const QString &category,
 
 void ActivityInfoTree::filterByDifficulty(quint32 levelMin, quint32 levelMax)
 {
-    //todo fix here the difficulty filtering
     auto it = std::remove_if(m_menuTree.begin(), m_menuTree.end(),
                              [&](const ActivityInfo *activity) {
                                  return activity->minimalDifficulty() < levelMin || activity->maximalDifficulty() > levelMax;
@@ -290,9 +289,9 @@ void ActivityInfoTree::filterBySearch(const QString &text)
             const auto &constMenuTreeFull = m_menuTreeFull;
             for (const auto &activity: constMenuTreeFull) {
                 /* clang-format off */
-                if (activity->title().contains(trimmedText, Qt::CaseInsensitive) ||
-                    activity->name().contains(trimmedText, Qt::CaseInsensitive) ||
-                    activity->description().contains(trimmedText, Qt::CaseInsensitive)) {
+                if (activity->title().remove(QChar::SoftHyphen).contains(trimmedText, Qt::CaseInsensitive) ||
+                    activity->name().remove(QChar::SoftHyphen).contains(trimmedText, Qt::CaseInsensitive) ||
+                    activity->description().remove(QChar::SoftHyphen).contains(trimmedText, Qt::CaseInsensitive)) {
                     /* clang-format on */
                     // add the activity only if it's not added
                     if (m_menuTree.indexOf(activity) == -1)
@@ -325,7 +324,7 @@ QVariantList ActivityInfoTree::allCharacters()
     for (const auto &tree: constMenuTreeFull) {
         const QString &title = tree->title();
         for (const QChar &letter: title) {
-            if (!letter.isSpace() && !letter.isPunct()) {
+            if (letter.isLetterOrNumber() || letter == QLatin1Char('-')) {
                 keyboardChars.insert(letter.toLower());
             }
         }
@@ -333,7 +332,9 @@ QVariantList ActivityInfoTree::allCharacters()
     for (const QChar &letters: keyboardChars) {
         m_keyboardCharacters.push_back(letters);
     }
-    std::sort(m_keyboardCharacters.begin(), m_keyboardCharacters.end(), [](const QVariant &v1, const QVariant &v2) { return v1.toChar() < v2.toChar(); });
+    std::sort(m_keyboardCharacters.begin(), m_keyboardCharacters.end(), [](const QVariant &v1, const QVariant &v2) {
+        return ApplicationInfo::getInstance()->localeCompare(v1.toString(), v2.toString()) < 0;
+    });
 
     return m_keyboardCharacters;
 }
