@@ -1,22 +1,11 @@
 /* GCompris - File.cpp
  *
- * Copyright (C) 2014,2015 Holger Kaelberer <holger.k@elberer.de>
+ * SPDX-FileCopyrightText: 2014, 2015 Holger Kaelberer <holger.k@elberer.de>
  *
  * Authors:
  *   Holger Kaelberer <holger.k@elberer.de>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include "File.h"
@@ -26,7 +15,8 @@
 #include <QString>
 #include <QTextStream>
 
-File::File(QObject *parent) : QObject(parent)
+File::File(QObject *parent) :
+    QObject(parent)
 {
 }
 
@@ -58,39 +48,43 @@ void File::setName(const QString &str)
     }
 }
 
-QString File::read(const QString& name)
+QString File::read(const QString &name)
 {
     if (!name.isEmpty())
         setName(name);
 
-    if (m_name.isEmpty()){
+    if (m_name.isEmpty()) {
         emit error("source is empty");
         return QString();
     }
 
     QFile file(m_name);
     QString fileContent;
-    if (file.open(QIODevice::ReadOnly) ) {
+    if (file.open(QIODevice::ReadOnly)) {
         QString line;
         QTextStream t(&file);
         /* Force utf-8 : for some languages, it seems to be loaded in other
           encoding even if the file is in utf-8 */
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        t.setEncoding(QStringConverter::Utf8);
+#else
         t.setCodec("UTF-8");
-
+#endif
         do {
             line = t.readLine();
             fileContent += line;
-         } while (!line.isNull());
+        } while (!line.isNull());
 
         file.close();
-    } else {
+    }
+    else {
         emit error("Unable to open the file");
         return QString();
     }
     return fileContent;
 }
 
-bool File::write(const QString& data, const QString& name)
+bool File::write(const QString &data, const QString &name)
 {
     if (!name.isEmpty())
         setName(name);
@@ -107,6 +101,12 @@ bool File::write(const QString& data, const QString& name)
     }
 
     QTextStream out(&file);
+    /* Force utf-8 : needed at least for Windows */
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    out.setEncoding(QStringConverter::Utf8);
+#else
+    out.setCodec("UTF-8");
+#endif
     out << data;
 
     file.close();
@@ -114,7 +114,7 @@ bool File::write(const QString& data, const QString& name)
     return true;
 }
 
-bool File::append(const QString& data, const QString& name)
+bool File::append(const QString &data, const QString &name)
 {
     if (!name.isEmpty())
         setName(name);
@@ -132,7 +132,12 @@ bool File::append(const QString& data, const QString& name)
 
     QTextStream out(&file);
     /* Force utf-8 : needed at least for Windows */
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    out.setEncoding(QStringConverter::Utf8);
+#else
     out.setCodec("UTF-8");
+#endif
+
     out << data;
 
     file.close();
@@ -140,18 +145,18 @@ bool File::append(const QString& data, const QString& name)
     return true;
 }
 
-bool File::exists(const QString& path)
+bool File::exists(const QString &path)
 {
     return QFile::exists(sanitizeUrl(path));
 }
 
-bool File::mkpath(const QString& path)
+bool File::mkpath(const QString &path)
 {
     QDir dir;
     return dir.mkpath(dir.filePath(sanitizeUrl(path)));
 }
 
-bool File::rmpath(const QString& path)
+bool File::rmpath(const QString &path)
 {
     return QFile::remove(sanitizeUrl(path));
 }
